summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoTextFormatter.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoTextFormatter.cpp')
-rw-r--r--lib/kotext/KoTextFormatter.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/kotext/KoTextFormatter.cpp b/lib/kotext/KoTextFormatter.cpp
index 7bdfbc0c..d978ba43 100644
--- a/lib/kotext/KoTextFormatter.cpp
+++ b/lib/kotext/KoTextFormatter.cpp
@@ -131,8 +131,8 @@ int KoTextFormatterCore::leftMargin( bool firstLine, bool includeFirstLineMargin
left += parag->firstLineMargin();
// Add the width of the paragraph counter - first line of parag only.
if( parag->counter() &&
- ( parag->counter()->tqalignment() == TQt::AlignLeft ||
- parag->counter()->tqalignment() == TQt::AlignAuto ) )
+ ( parag->counter()->alignment() == TQt::AlignLeft ||
+ parag->counter()->alignment() == TQt::AlignAuto ) )
left += parag->counterWidth(); // in LU pixels
}
return left;
@@ -251,9 +251,9 @@ bool KoTextFormatterCore::format()
bool lastWasNonInlineCustom = FALSE;
bool abort = false;
- int align = parag->tqalignment();
- if ( align == TQt::AlignAuto && doc && doc->tqalignment() != TQt::AlignAuto )
- align = doc->tqalignment();
+ int align = parag->alignment();
+ if ( align == TQt::AlignAuto && doc && doc->alignment() != TQt::AlignAuto )
+ align = doc->alignment();
int col = 0;
@@ -810,7 +810,7 @@ KoTextParagLineStart *KoTextFormatterCore::koFormatLine(
if (space < 0)
space = 0;
// do tqalignment Auto == Left in this case
if ( align & TQt::AlignHCenter || align & TQt::AlignRight ) {
if ( align & TQt::AlignHCenter )
space /= 2;
@@ -949,7 +949,7 @@ KoTextParagLineStart *KoTextFormatterCore::koBidiReorderLine(
// now construct the reordered string out of the runs...
int numSpaces = 0;
// set the correct tqalignment. This is a bit messy....
if( align == TQt::AlignAuto ) {
// align according to directionality of the paragraph...
if ( text->isRightToLeft() )
@@ -810,7 +810,7 @@ KoTextParagLineStart *KoTextFormatterCore::koFormatLine(
if (space < 0)
space = 0;
- // do tqalignment Auto == Left in this case
+ // do alignment Auto == Left in this case
if ( align & TQt::AlignHCenter || align & TQt::AlignRight ) {
if ( align & TQt::AlignHCenter )
@@ -949,7 +949,7 @@ KoTextParagLineStart *KoTextFormatterCore::koBidiReorderLine(
// now construct the reordered string out of the runs...
int numSpaces = 0;
- // set the correct tqalignment. This is a bit messy....
+ // set the correct alignment. This is a bit messy....
if( align == TQt::AlignAuto ) {
// align according to directionality of the paragraph...